﻿[ ] // **********************************************************************************************************************************************************************************************
[ ] // POS AUTOMATION_V11
[ ] // INCLUDE FILE
[ ] // FILE NAME : POSOPERATIONS.INC
[ ] // DESCRIPTION : This file contains functions specific to system properties of POS
[ ] // Author : Chiranjeev Banerjee
[ ] // **********************************************************************************************************************************************************************************************
[ ] 
[+] // % QA DIRECTOR
	[+] BOOLEAN IsQAD ()
		[ ] //#
		[ ] //returns:	BOOLEAN:
		[ ] //notes:	Checks to see if QAD Suite ID environment variable is there.
		[ ] //#
		[ ] return Val (HOST_GetEnv ("QC_SUITE_ID"))
	[+] SubtestCleanup () 
		[ ] //#
		[ ] //returns:	VOID:
		[ ] //notes:	If running subtests this will try to cleanup before the next test
		[ ] //#
		[ ] 
		[+] if QuickBooksPointOfSale.Exists()
			[ ] // Closing POS completly
			[+] if QuickBooksPointOfSale.Exists()
				[+] if (QuickBooksPointOfSale.File.Exists ())
					[ ] QuickBooksPointOfSale.File.Click ()
					[ ] QuickBooksPointOfSale.File.Exit.Click ()
	[+] StartSubtest (STRING sSubtestName)
		[ ] //#
		[ ] //returns:	VOID:
		[ ] //parameter:	STRING sSubtestName: string name of subtest
		[ ] //notes:	If running subtests this will send cmd line to start subtest
		[ ] //#
		[ ] 
		[ ] BOOLEAN bQAD = IsQAD ()
		[+] if (bQAD)
			[ ] STRING subtest_start = "{sCompuwareExe} subtest_start "
			[+] if (Len(sSubtestName) > 50) 
				[ ] sSubtestName = SubStr(sSubtestName, 1, 50)
			[ ] STRING execstr = subtest_start + """" + sSubtestName + """"
			[ ] SYS_Execute(execstr)
	[+] PassSubtest ()		
		[ ] //#
		[ ] //returns:	VOID:
		[ ] //notes:	If running subtests this will send cmd line to report a "pass"
		[ ] //#
		[ ] 
		[ ] BOOLEAN bQAD = IsQAD ()
		[+] if (bQAD)
			[ ] STRING subtest_pass = "{sCompuwareExe} subtest_pass"
			[ ] SYS_Execute(subtest_pass)
	[+] FailSubtest (STRING sFailureReason)
		[ ] //#
		[ ] //returns:	VOID:
		[ ] //notes:	If running subtests this will send cmd line to report a "fail"
		[ ] //#
		[ ] 
		[ ] BOOLEAN bQAD = IsQAD ()
		[+] if (bQAD)
			[ ] STRING subtest_fail = "{sCompuwareExe} subtest_fail "
			[+] if (Len(sFailureReason) > 180) 
				[ ] sFailureReason = SubStr(sFailureReason, 1, 180)
			[ ] STRING execstr = subtest_fail + """" + sFailureReason + """"
			[ ] SYS_Execute(execstr)
[ ] 
[-] // % EXCEPTION HANDLING
	[ ] 
	[+] type Result is record
		[ ] STRING sDesc
		[ ] BOOLEAN bResult
		[ ] ANYTYPE aActual
		[ ] ANYTYPE aExpected
	[ ] 
	[ ] LIST OF Result lrMaster
	[ ] 
	[+] AddError (STRING sError)
		[ ] ListAppend (lrMaster, {sError, FALSE, NULL, NULL})
		[ ] 
		[ ] LogError (sError)
	[ ] 
	[+] RunRecover ()
		[ ] // This function attempts to get a user back to a clean logged in state and ready
		[ ] // for the next action since it probably failed on the last iteration.
		[ ] 
		[ ] LIST OF STRING lsInfo
		[ ] 
		[+] // close all windows in POS.
			[ ] wWin = QuickBooksPointOfSale.GetNextCloseWindow ()
			[ ] wWin.Close ()
		[ ] 
		[ ] // if a file is open clean up UI
		[+] if (QuickBooksPointOfSale.File.IsEnabled ())
			[ ] Print ("POS is open. Closing all windows.")
			[ ] QuickBooksPointOfSale.File.Click ()
			[ ] QuickBooksPointOfSale.File.Exit.Click ()
		[+] else
			[ ] // if it's not open or a window is blocking the menu, take QB out!
			[ ] // we might want to know what the window is.
			[ ] // check if a window is blocking:
			[ ] WINDOW wWin = QuickBooksPointOfSale.GetNextCloseWindow()
			[ ] Print ("Checking if a window is blocking. Current window is {wWin.sCaption}. Killing POS process and stopping the DB")
			[ ] 
			[ ] SYS_Execute(sPVPath + " -k -f QBPOSShell.exe")			//Check
[ ] 
[-] // % RECOVERY SYSTEM
	[ ] BOOLEAN bScriptEnterException = FALSE
	[ ] BOOLEAN bTestCaseExitException = FALSE
	[ ] 
	[+] TestCaseEnter ()
		[ ] 
		[ ] DefaultTestCaseEnter ()
		[ ] 
		[ ] lrMaster = {}
		[ ] Print ("=================================================")
	[ ] 
	[-] TestCaseExit (BOOLEAN bException)
		[ ] 
		[ ] Result rResult
		[ ] // If an exception occur in TestCaseExit, it goes to ScriptExit, bypassing error logging to QAD which occur below
		[ ] bTestCaseExitException = TRUE 
		[ ] 
		[ ] // Capture Bitmap.   IF THERE WAS AN ERROR THAT CAUSED THE TESTCASE TO EXIT, CAPTURE BITMAP OF SCREEN
		[+] if (bException)
			[ ] STRING sException = ExceptData ()
			[ ] ListAppend (lrMaster, {"Unexpected Error", FALSE, sException, NULL})
			[ ] 
			[+] do
				[+] if !(SYS_DirExists (sResultsDir))
					[ ] SYS_MakeDir (sResultsDir)
					[ ] LogWarning ("Created results directory - {sResultsDir}")
				[ ] 
				[ ] Agent.SetOption (OPT_BITMAP_MATCH_COUNT, 1)
				[ ] Desktop.CaptureBitmap ("{sResultsDir}\{GetTestCaseName ()}.bmp")
				[ ] Print ("POS bitmap captured - {sResultsDir}\{GetTestCaseName ()}.bmp")
			[+] except
				[ ] LogWarning ("Unable to capture bitmap - {[EXCEPTION]ExceptNum ()}")
		[ ] 
		[ ] // Close POS after the execution of every script
		[ ] //CloseProcess("QBPOSShell.exe") 
		[ ] //CloseProcess("qbpos.exe")
		[ ] //CloseProcess ("iexplore.exe")
		[ ] 
		[-] if (bException)
			[ ] ResOpenList("Test Case Exit")
			[ ] //if it is a verify exception then skip the closing or killing of CRP.
			[-] if (ExceptNum() != E_VERIFY)
				[ ] CloseProcess("QBPOSShell.exe")
				[ ] CloseProcess("qbpos.exe")
			[ ] Print ()
			[ ] ResCloseList()
		[ ] 
		[ ] BOOLEAN bQAD = IsQAD ()
		[ ] 
		[ ] // PRINT EACH RESULT TO RESULTS FILE
		[ ] // GO THROUGH EACH RESULT IN LIST OF RESULTS AND SEND TO QAD IF APPLICABLE
		[ ] Print ("- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -")
		[ ] print ()
		[+] for each rResult in lrMaster
			[+] if (bQAD)
				[ ] StartSubtest (rResult.sDesc)
				[+] switch rResult.bResult
					[+] case TRUE
						[ ] PassSubtest ()
					[+] case FALSE
						[+] if (rResult.aExpected != NULL)
							[ ] FailSubtest ("Got '{rResult.aActual}' expected '{rResult.aExpected}'")
						[+] else
							[ ] FailSubtest (rResult.aActual)
			[ ] Print ("Test '{rResult.sDesc}' {rResult.bResult ? "Passed" : "Failed"}")
		[ ] 
		[ ] bTestCaseExitException = FALSE
		[+] if (bException)
			[ ] ExceptLog ()
		[ ] 
		[ ] // DefaultTestCaseExit (bException)
	[ ] 
	[+] ScriptEnter ()
		[ ] LIST OF STRING lsClassMappings
		[ ] NUMBER nKeyBoardDelayTime = 0.05
		[ ] NUMBER nMouseDelayTime = 0.5
		[ ] NUMBER nWaitWindowDelayTime = 2 
		[ ] NUMBER nWaitWindActiveTime = 5
		[ ] Agent.SetOption(OPT_HANG_APP_TIME_OUT, 10001)
		[ ] Agent.SetOption (OPT_KEYBOARD_DELAY, nKeyBoardDelayTime)
		[ ] Agent.SetOption (OPT_MOUSE_DELAY, nMouseDelayTime)
		[ ] SYS_SetDir (GetPOSPath ())
		[ ] AddAgentOptions ()
		[ ] DefaultScriptEnter ()
	[ ] 
	[+] ScriptExit (BOOLEAN bException)
		[ ] STRING sQADEnv = ""
		[ ] Agent.SetOption(OPT_HANG_APP_TIME_OUT, 10.0)
		[ ] 
		[+] if (bException)
			[+] if (bScriptEnterException)
				[ ] LogError ("*** ScriptEnter Exception: An error occurred prior to running the testcase.") 
			[+] else if (bTestCaseExitException)
				[ ] LogError ("*** TestCase Exit Exception: An error occurred in the recovery system.")
			[+] else
				[ ] LogError ("*** Unknown Error: An error occurred in the recovery system.")
			[ ] 
			[ ] ExceptLog ()
			[ ] sQADEnv = SYS_GetEnv("AL_FAIL_STATUS")
			[ ] print ("The AL_FAIL_STATUS env var = {sQADEnv}")
			[+] if (sQADEnv != "")
				[ ] // if it did then set the env value to 1
				[ ] SYS_SetEnv ("AL_FAIL_STATUS", "1")
			[ ] 
			[ ] // Take screenshot of Desktop
			[ ] Agent.SetOption (OPT_BITMAP_MATCH_COUNT, 1)
			[ ] Desktop.CaptureBitmap ("{sResultsDir}\Desktop.bmp")
			[ ] Print ("Desktop Bitmap captured - {sResultsDir}\Desktop.bmp")
			[ ] 
		[ ] DefaultScriptExit (bException)
[ ] 
[-] // FUNCTIONS
	[+] BOOLEAN CloseProcess (STRING sProcessToClose, INTEGER iTimeout optional)
		[ ] //#
		[ ] // returns: 	BOOLEAN: returns 0 of the process did not get closed and 1 if it got closed or was not there
		[ ] // notes:	Function to close a process. Uses pskill
		[ ] // parameter:	sProcess: Name of process.
		[ ] // parameter:	iTimeout: Duration to keep checking for process. Optional
		[ ] //#
		[ ] 
		[ ] BOOLEAN bProcessGone = FALSE 	// Initialze to assume process is there
		[ ] 
		[ ] //Check if process is there
		[ ] bProcessGone=SYS_Execute(sPVPath + " -a {sProcessToClose}")
		[+] if bProcessGone == FALSE
			[ ] print("====== Try to close {sProcessToClose}... ======")
			[ ] SYS_Execute(sPVPath + " -K -f {sProcessToClose}")
			[ ] WaitForProcessToClose(sProcessToClose, 6)
			[ ] //Check to see if it is there still
			[ ] bProcessGone=SYS_Execute(sPVPath + " -a {sProcessToClose}")
			[+] if bProcessGone == FALSE
				[ ] print("*********** Could not close {sProcessToClose} process. **************")
				[ ] bProcessGone = FALSE
			[+] else
				[ ] print(">>>>>>>> Process {sProcessToClose} successfully closed. <<<<<<<<")
				[ ] bProcessGone = TRUE
		[+] else
			[ ] print("*********** Process {sProcessToClose} does not exist. Cannot close process. *****************")
			[ ] bProcessGone = TRUE
		[ ] 
		[ ] 
		[ ] // Kill the process incase not able to close
		[-] if !(bProcessGone)
			[ ] print ("Killing the {sProcessToClose}...........................")
			[ ] SYS_Execute(sPVPath + " -k -f {sProcessToClose}")
			[-] if !(SYS_Execute(sPVPath + " -a QBPOSShell.exe"))
				[ ] print ("Killing the IntuitUpdater.exe............................")
				[ ] SYS_Execute(sPVPath + " -k -f  QBPOSShell.exe")
				[ ] bProcessGone = TRUE
		[ ] return bProcessGone
	[+] WaitForProcessToClose(STRING sProcess, INTEGER iTimeout optional)
		[ ] // #
		[ ] // returns: 	VOID: 
		[ ] // notes:	Function to wait for a process to be killed or closed before continuing. Uses pskill
		[ ] // parameter:	sProcess: Name of process 
		[ ] // parameter:	iTimeout: Duration to keep checking for process. Optional
		[ ] // #
		[ ] 
		[ ] INTEGER iLoop
		[ ] BOOLEAN bProcessGone = FALSE //meaning the process is there: activation success= 0
		[+] if iTimeout == NULL
			[ ] iTimeout = 40
		[ ] sleep(1)
		[+] for iLoop = 1 to iTimeout
			[ ] //Checks process to see if still active
			[ ] bProcessGone=  SYS_Execute("q:\bin\PrcView\pv.exe -a {sProcess}") 
			[+] if bProcessGone == TRUE
				[ ] break
			[+] else
				[ ] sleep(1)
		[+] if (iLoop >= iTimeout)
			[ ] print("{sProcess} did NOT close  in {iTimeout} seconds.")
		[+] else
			[ ] print("{sProcess} closed in {iLoop} seconds.")
		[ ] Sleep(1)
	[+] STRING GetPosVersion()
		[ ] // #
		[ ] // returns: 	STRING: returns the Verison
		[ ] // notes:	Function to get the GetPos version number
		[ ] // parameter:	Nill
		[ ] // #
		[ ] LIST OF STRING lsVersions, lsRegOut
		[ ] STRING sVersion, sRegOut, sPOSVersion
		[ ] lsVersions = SYS_GetRegistryKeynames (HKEY_LOCAL_MACHINE, "SOFTWARE\Intuit\QuickBooks")
		[+] for each sVersion in lsVersions
			[ ] lsRegOut = SYS_GetRegistryKeynames (HKEY_LOCAL_MACHINE, "SOFTWARE\Intuit\QuickBooks\{sVersion}")
			[+] for each sRegOut in lsRegOut
				[+] if (ListFind (lsRegOut, "pos") != 0)
					[ ] sPOSVersion = sVersion
					[ ] break
		[ ] return sPOSVersion
	[-] STRING GetOSBit ()
		[-] if SYS_DirExists ("C:\Program Files (x86)")
			[ ] return "bit64"
		[-] else
			[ ] return "bit32"
	[-] STRING GetPOSPath ()
		[ ] // #
		[ ] // returns: 	STRING: returns installed path for POS
		[ ] // notes:	Function to get the  installed path for POS
		[ ] // parameter:	Nill
		[ ] // #
		[ ] STRING sPath, sVer, sTry, sBit
		[ ] sVer = GetPosVersion ()
		[ ] sPath = SYS_GetRegistryValue(HKEY_LOCAL_MACHINE, "SOFTWARE\Intuit\QuickBooks\{sVer}\pos", "TARGET_PATH")
		[ ] return sPath
	[-] STRING GetPOSExe ()
		[ ] //#
		[ ] //returns:		STRING
		[ ] //parameter:	none
		[ ] //notes: Returns full path and executable of specified version. Uses sQBVersion, if it is not set
		[ ] //then uses the method called GetLatestQBVer
		[ ] //#
		[ ] 
		[ ] STRING sPath, sPOSExe
		[ ] sPath = GetPOSPath ()
		[ ] sPOSExe = sPath+"QBPOSShell.exe"
		[ ] return sPOSExe
	[-] STRING GetPOSIniFilePath ()
		[-] switch GetGuiType ()
			[-] case mswxp, mswxp64
				[ ] return "C:\Documents and Settings\All Users\Application Data\Intuit\{GetField(GetPOSPath (),"\",4)}\Ini"
			[-] case msw2003, msw2003_64
				[ ] return "C:\Documents and Settings\All Users\Application Data\Intuit\{GetField(GetPOSPath (),"\",4)}\Ini"
			[+] case mswvista, mswvista_64
				[ ] return "C:\ProgramData\Intuit\{GetField(GetPOSPath (),"\",4)}\Ini"
			[-] case mswin7, mswin7_64
				[ ] return "C:\ProgramData\Intuit\{GetField(GetPOSPath (),"\",4)}\Ini"
			[+] // case mswin8, mswin8_64
				[ ] // return "C:\ProgramData\Intuit\{GetField(GetPOSPath (),"\",4)}\Ini"
			[+] case mswin2008, mswin2008_64
				[ ] return "C:\ProgramData\Intuit\{GetField(GetPOSPath (),"\",4)}\Ini"
	[-] STRING GetPOSFilePath (STRING sCompanyFile)
		[ ] //#
		[ ] //returns:  STRING: Return Type
		[ ] //parameter: STRING sFeature - name of the feature folder where company file resides
		[ ] //parameter: STRING sFile - name of the file
		[ ] //notes:     It gets the company file based on the bel or non-bel
		[ ] //#
		[ ] 
		[ ] STRING  sVersion, sCompanyPath, sDir 
		[ ] 
		[+] LIST OF STRING lsVersion = {...}
			[ ] "22.0"
			[ ] "21.0"
			[ ] "20.0"
			[ ] "19.0"
			[ ] "18.0"
			[ ] "17.0"
			[ ] "16.0"
		[ ] 
		[+] if (ListFind (lsVersion, GetPosVersion()) == 0)
			[ ] Print( " {GetPosVersion()} is not available in list adding the version number to the list")
			[ ] ListAppend (lsVersion, GetPosVersion())
		[ ] 
		[+] for each sVersion in lsVersion
			[ ] ResOpenList ("Searching the company file in the folder {sCompanyFileSource}\{sVersion}..........."  )
			[ ] sCompanyPath = "{sCompanyFileSource}\{sVersion}\{sCompanyFile}"
			[ ] //Print (sDir)
			[+] if (SYS_FileExists (sCompanyPath))
				[ ] Print ("Found the company file in path {sCompanyPath}...........")
				[ ] ResCloseList ()
				[ ] return sCompanyPath
			[ ] ResCloseList ()
		[ ] 
		[ ] return ""
		[ ] 
	[-] BOOLEAN KILLPOS ()	
		[ ] INTEGER iCount = 1
		[+] while  (!QuickBooksPointOfSale.File.IsEnabled ())
			[ ] Print ("Attempt to close unexpected window with default case  ")
			[ ] Print (QuickBooksPointOfSale.GetNextCloseWindow ())
			[ ] window wUnhandled = QuickBooksPointOfSale.GetNextCloseWindow ()
			[ ] wUnhandled.Close ()
			[ ] iCount++
			[+] if iCount <= 10
				[ ] break
				[ ] return FALSE
			[ ] 
		[ ] QuickBooksPointOfSale.File.Click ()
		[ ] QuickBooksPointOfSale.File.Exit.Click ()
		[ ] QuickBooksPointOfSale.ExitDialog.Yes.Click ()
		[ ] Sleep (30)
		[ ] CloseProcess("QBPOSShell.exe") 
		[ ] return TRUE
	[+] STRING GetCurrentCompanyName ()
		[ ] 
		[ ] return Trim(GetField (QuickBooksPointOfSale.HeaderText.GetCaption (), "- QuickBooks Point of Sale", 1))
		[ ] 
	[+] STRING  GetSKUFromHeader ()
		[ ] QuickBooksPointOfSale.SetActive ()
		[ ] STRING sSKU =  GetField (QuickBooksPointOfSale.HeaderText.GetCaption (), "- QuickBooks Point of Sale", 2)
		[+] select 
			[+] case (MatchStr ("*Multistore*", sSKU))
				[ ] return "MULTISTORE"
			[+] case (MatchStr ("*Basic*", sSKU))
				[ ] return "BASIC"
			[+] case (MatchStr ("*Pro*", sSKU))
				[ ] return "PRO"
			[+] case (MatchStr ("*Free*", sSKU))
				[ ] return "FREE"
			[+] default 
				[ ] Print ("Cant Deside the SKU.......... ")
				[ ] return NULL
	[-] STRING GetVer ()
		[ ] LIST OF FILEINFO lfInfo
		[ ] FILEINFO fInfo
		[-] switch GetOSBit ()
			[-] case "bit32"
				[ ] lfInfo = SYS_GetDirContents ("C:\Program Files\Intuit\")
			[-] case "bit64"
				[ ] lfInfo = SYS_GetDirContents ("C:\Program Files (x86)\Intuit\")
			[-] default
				[ ] lfInfo = SYS_GetDirContents ("C:\Program Files\Intuit\")
		[+] for each fInfo in lfInfo
			[+] if fInfo.bIsDir == TRUE
				[+] if MatchStr ("QuickBooks Point of Sale *", fInfo.sName)
					[ ] return (GetField (fInfo.sName, "Sale ", 2))
		[ ] 
	[-] STRING GetPOSDataPath ()
		[-] switch GetGuiType ()
			[-] case  mswxp, mswxp64
				[ ] return "{sLocalPath}Documents and Settings\All Users\Documents\Intuit\QuickBooks Point of Sale {GetVer ()}\Data\"
			[-] case  msw2003, msw2003_64
				[ ] return "{sLocalPath}Documents and Settings\All Users\Documents\Intuit\QuickBooks Point of Sale {GetVer ()}\Data\"
			[-] case  mswvista, mswvista_64
				[ ] return "{sLocalPath}Users\Public\Documents\Intuit\QuickBooks Point of Sale {GetVer ()}\Data\"
			[-] case  mswin7, mswin7_64
				[ ] return "{sLocalPath}Users\Public\Documents\Intuit\QuickBooks Point of Sale 12.0\Data\"
			[+] // case  mswin8, mswin8_64
				[ ] // return "{sLocalPath}Users\Public\Documents\Intuit\QuickBooks Point of Sale {GetVer ()}\Data\"
			[-] case  mswin2008, mswin2008_64
				[ ] return "{sLocalPath}Users\Public\Documents\Intuit\QuickBooks Point of Sale {GetVer ()}\Data\"
			[-] default
				[ ] ///return "{sLocalPath}Documents and Settings\All Users\Documents\Intuit\QuickBooks Point of Sale {GetVer ()}\Data\"
				[ ] return "{sLocalPath}Users\Public\Documents\Intuit\QuickBooks Point of Sale {GetVer ()}\Data\"
	[+] VOID AddAgentOptions ()
		[ ] //LIST OF STRING lsClassMappings = AddClassMappings ()
		[ ] NUMBER nWinDelayTime, nKeyMouseDelayTime
		[ ] 
		[ ] nWinDelayTime = Val (SYS_GetEnv ("DELAY"))
		[ ] // If nothing is specified for environment variable DELAY then use the default of 20 seconds
		[ ] // Use a minum of 60 seconds and a maximum of 120 seconds 
		[ ] // if in case you are working on McCabe or Vista machines.
		[+] if (nWinDelayTime == 0)
			[+] if (GetGuiType () == mswvista)
				[ ] nWinDelayTime = 30
				[ ] 
				[ ] // Set the Agent option of verifing active windows to false
				[ ] Agent.SetOption (OPT_WINDOW_RETRY, 3)
				[ ] Agent.SetOption (OPT_REQUIRE_ACTIVE, FALSE)
				[ ] 
			[+] else
				[ ] nWinDelayTime = 20
		[ ] 
		[ ] // Compute keyboard and mouse delay based on the window delay
		[ ] // 1/2000th of window delay time
		[ ] // nKeyMouseDelayTime = nWinDelayTime / 2000
		[ ] Agent.SetOption (OPT_WINDOW_TIMEOUT, nWinDelayTime)
		[ ] NUMBER nKeyBoardDelayTime = 0.05
		[ ] NUMBER nMouseDelayTime = 1
		[ ] Agent.SetOption (OPT_KEYBOARD_DELAY, nKeyBoardDelayTime)
		[ ] Agent.SetOption (OPT_MOUSE_DELAY, nMouseDelayTime)
		[ ] 
		[ ] 
	[+] // CaptureCheckBoxBitmap ()
		[ ] // RECT r, rPos
		[ ] // // Capturing bitmap for left checkbox
		[ ] // Preferences.CompanyPreferences.Invoke ()
		[ ] // Preferences.CompanyPreferences.TreeView.SetFocus ()
		[ ] // Preferences.CompanyPreferences.TreeView.Select ("General")
		[ ] // r = Preferences.CompanyPreferences.PageList.General.Options.BringBackAllOneTimeMessag.GetRect ()
		[ ] // rPos.xPos = 0
		[ ] // rPos.xSize = r.ySize
		[ ] // rPos.yPos = 0
		[ ] // rPos.ySize = r.ySize
		[ ] // STRING sBitmap = "{sBitmapPath}\LUnCheckBox.bmp"
		[ ] // Preferences.CompanyPreferences.PageList.General.Options.BringBackAllOneTimeMessag.CaptureBitmap (sBitmap, rPos)
		[ ] // Print ("Bitmap for UnCheck state of CheckBox captured and stored in {sBitmap}")
		[ ] // Preferences.CompanyPreferences.PageList.General.Options.BringBackAllOneTimeMessag.Click ()
		[ ] // sBitmap = "{sBitmapPath}\LCheckBox.bmp"
		[ ] // Preferences.CompanyPreferences.PageList.General.Options.BringBackAllOneTimeMessag.CaptureBitmap (sBitmap, rPos)
		[ ] // Print ("Bitmap for Check state of CheckBox captured and stored in {sBitmap}")
		[ ] // Preferences.CompanyPreferences.PageList.General.Options.BringBackAllOneTimeMessag.Click ()
		[ ] // Preferences.BottomBar.Cancel.Click ()
		[ ] // 
		[ ] // // Capturing bitmap for right checkbox
		[ ] // Vendor.NewVendor.Invoke ()
		[ ] // Sleep (5)
		[ ] // r = Vendor.NewVendor.PageList.Inactive.GetRect ()
		[ ] // rPos.xPos = r.xSize - r.ySize
		[ ] // rPos.xSize = r.ySize
		[ ] // rPos.yPos = 0
		[ ] // rPos.ySize = r.ySize
		[ ] // sBitmap = "{sBitmapPath}\RUnCheckBox.bmp"
		[ ] // Vendor.NewVendor.PageList.Inactive.CaptureBitmap (sBitmap, rPos)
		[ ] // Print ("Bitmap for UnCheck state of CheckBox captured and stored in {sBitmap}")
		[ ] // Vendor.NewVendor.PageList.Inactive.Click ()
		[ ] // sBitmap = "{sBitmapPath}\RCheckBox.bmp"
		[ ] // Vendor.NewVendor.PageList.Inactive.CaptureBitmap (sBitmap, rPos)
		[ ] // Print ("Bitmap for Check state of CheckBox captured and stored in {sBitmap}")
		[ ] // Vendor.NewVendor.PageList.Inactive.Click ()
		[ ] // Vendor.BottomBar.Cancel.Click ()
		[ ] // VendorInProgress.Yes.Click ()
		[ ] // VendorList.BottomBar.Close.Click ()
	[+] CaptureCheckBoxBitmap ()
		[ ] RECT r, rPos
		[ ] STRING sBitmap
		[+] // // Capturing bitmap for left checkbox
			[ ] // Preferences.CompanyPreferences.Invoke ()
			[ ] // Preferences.CompanyPreferences.TreeView.SetFocus ()
			[ ] // Preferences.CompanyPreferences.TreeView.Select ("General")
			[ ] // r = Preferences.CompanyPreferences.PageList.General.Options.BringBackAllOneTimeMessag.GetRect ()
			[ ] // rPos.xPos = 0
			[ ] // rPos.xSize = r.ySize
			[ ] // rPos.yPos = 0
			[ ] // rPos.ySize = r.ySize
			[ ] // sBitmap = "{sBitmapPath}\LUnCheckBox.bmp"
			[ ] // Preferences.CompanyPreferences.PageList.General.Options.BringBackAllOneTimeMessag.CaptureBitmap (sBitmap, rPos)
			[ ] // Print ("Bitmap for UnCheck state of CheckBox captured and stored in {sBitmap}")
			[ ] // Preferences.CompanyPreferences.PageList.General.Options.BringBackAllOneTimeMessag.Click ()
			[ ] // sBitmap = "{sBitmapPath}\LCheckBox.bmp"
			[ ] // Preferences.CompanyPreferences.PageList.General.Options.BringBackAllOneTimeMessag.CaptureBitmap (sBitmap, rPos)
			[ ] // Print ("Bitmap for Check state of CheckBox captured and stored in {sBitmap}")
			[ ] // Preferences.CompanyPreferences.PageList.General.Options.BringBackAllOneTimeMessag.Click ()
			[ ] // Preferences.BottomBar.Cancel.Click ()
		[ ] 
		[+] // Capturing bitmap for left checkbox
			[ ] Preferences.CompanyPreferences.Invoke ()
			[ ] Sleep (2)
			[ ] Preferences.CompanyPreferences.TreeView.SetFocus ()
			[ ] Sleep (2)
			[ ] Preferences.CompanyPreferences.TreeView.Select ("General")
			[ ] Sleep (2)
			[ ] r = Preferences.CompanyPreferences.PageList.General.Options.BringBackAllOneTimeMessag.GetRect ()
			[ ] rPos.xPos = 0
			[ ] rPos.xSize = r.ySize
			[ ] rPos.yPos = 0
			[ ] rPos.ySize = r.ySize
			[ ] sBitmap = "{sBitmapPath}\LUnCheckBox.bmp"
			[ ] Preferences.CompanyPreferences.PageList.General.Options.BringBackAllOneTimeMessag.CaptureBitmap (sBitmap, rPos)
			[ ] Print ("Bitmap for UnCheck state of CheckBox captured and stored in {sBitmap}")
			[ ] Preferences.CompanyPreferences.PageList.General.Options.BringBackAllOneTimeMessag.Click ()
			[ ] sBitmap = "{sBitmapPath}\LCheckBox.bmp"
			[ ] Preferences.CompanyPreferences.PageList.General.Options.BringBackAllOneTimeMessag.CaptureBitmap (sBitmap, rPos)
			[ ] Print ("Bitmap for Check state of CheckBox captured and stored in {sBitmap}")
			[ ] Preferences.CompanyPreferences.PageList.General.Options.BringBackAllOneTimeMessag.Click ()
			[ ] 
			[ ] //  Capturing bitmap for left checkbox2
			[ ] Sleep (2)
			[ ] Preferences.CompanyPreferences.TreeView.SetFocus ()
			[ ] Sleep (2)
			[ ] Preferences.CompanyPreferences.TreeView.Select ("Discounts")
			[ ] Sleep (2)
			[ ] r = Preferences.CompanyPreferences.PageList.Discounts.ManualItemDiscountReason.RequireADiscountReasonForManualDiscount.GetRect ()
			[ ] rPos.xPos = 0
			[ ] rPos.xSize = r.ySize
			[ ] rPos.yPos = 0
			[ ] rPos.ySize = r.ySize
			[ ] sBitmap = "{sBitmapPath}\LUnCheckBox2.bmp"
			[ ] Preferences.CompanyPreferences.PageList.Discounts.ManualItemDiscountReason.RequireADiscountReasonForManualDiscount.CaptureBitmap (sBitmap, rPos)
			[ ] Print ("Bitmap for UnCheck state of CheckBox captured and stored in {sBitmap}")
			[ ] Preferences.CompanyPreferences.PageList.Discounts.ManualItemDiscountReason.RequireADiscountReasonForManualDiscount.Click ()
			[ ] sBitmap = "{sBitmapPath}\LCheckBox2.bmp"
			[ ] Preferences.CompanyPreferences.PageList.Discounts.ManualItemDiscountReason.RequireADiscountReasonForManualDiscount.CaptureBitmap (sBitmap, rPos)
			[ ] Print ("Bitmap for Check state of CheckBox captured and stored in {sBitmap}")
			[ ] Preferences.CompanyPreferences.PageList.Discounts.ManualItemDiscountReason.RequireADiscountReasonForManualDiscount.Click ()
			[ ] 
			[ ] //  Capturing bitmap for left checkbox3
			[ ] Sleep (2)
			[ ] Preferences.CompanyPreferences.TreeView.SetFocus ()
			[ ] Sleep (2)
			[ ] Preferences.CompanyPreferences.TreeView.Select ("Receipt Tendering")
			[ ] Sleep (2)
			[ ] r = Preferences.CompanyPreferences.PageList.ReceiptTenders.PaymentMethods.Check.GetRect ()
			[ ] rPos.xPos = 0
			[ ] rPos.xSize = r.ySize
			[ ] rPos.yPos = 0
			[ ] rPos.ySize = r.ySize
			[ ] sBitmap = "{sBitmapPath}\LCheckBox3.bmp"
			[ ] Preferences.CompanyPreferences.PageList.ReceiptTenders.PaymentMethods.Check.CaptureBitmap (sBitmap, rPos)
			[ ] Print ("Bitmap for Check state of CheckBox captured and stored in {sBitmap}")
			[ ] Preferences.CompanyPreferences.PageList.ReceiptTenders.PaymentMethods.Check.Click ()
			[ ] sBitmap = "{sBitmapPath}\LUnCheckBox3.bmp"
			[ ] Preferences.CompanyPreferences.PageList.ReceiptTenders.PaymentMethods.Check.CaptureBitmap (sBitmap, rPos)
			[ ] Print ("Bitmap for UnCheck state of CheckBox captured and stored in {sBitmap}")
			[ ] Preferences.CompanyPreferences.PageList.ReceiptTenders.PaymentMethods.Check.Click ()
			[ ] Sleep (2)
			[ ] Preferences.BottomBar.Cancel.Click ()
			[+] if CompanyPreferences.Exists (3)
				[ ] CompanyPreferences.No.Click ()
		[ ] 
		[+] // // Capturing bitmap for right checkbox
			[ ] // Sleep (2)
			[ ] // Vendor.NewVendor.Invoke ()
			[ ] // Sleep (5)
			[ ] // r = Vendor.NewVendor.PageList.Inactive.GetRect ()
			[ ] // rPos.xPos = r.xSize - r.ySize
			[ ] // rPos.xSize = r.ySize
			[ ] // rPos.yPos = 0
			[ ] // rPos.ySize = r.ySize
			[ ] // sBitmap = "{sBitmapPath}\RUnCheckBox.bmp"
			[ ] // Vendor.NewVendor.PageList.Inactive.CaptureBitmap (sBitmap, rPos)
			[ ] // Print ("Bitmap for UnCheck state of CheckBox captured and stored in {sBitmap}")
			[ ] // Vendor.NewVendor.PageList.Inactive.Click ()
			[ ] // sBitmap = "{sBitmapPath}\RCheckBox.bmp"
			[ ] // Vendor.NewVendor.PageList.Inactive.CaptureBitmap (sBitmap, rPos)
			[ ] // Print ("Bitmap for Check state of CheckBox captured and stored in {sBitmap}")
			[ ] // Vendor.NewVendor.PageList.Inactive.Click ()
			[ ] // Vendor.BottomBar.Cancel.Click ()
			[ ] // VendorInProgress.Yes.Click ()
			[ ] // VendorList.BottomBar.Close.Click ()
		[ ] 
		[+] // // Capturing bitmap for left checkbox2
			[ ] // CleanUpCompanyData.Invoke ()
			[ ] // r = CleanUpCompanyData.PageList1.Overview.CompressDatabase.GetRect ()
			[ ] // rPos.xPos = 0
			[ ] // rPos.xSize = r.ySize
			[ ] // rPos.yPos = 0
			[ ] // rPos.ySize = r.ySize
			[ ] // sBitmap = "{sBitmapPath}\LUnCheckBox2.bmp"
			[ ] // CleanUpCompanyData.PageList1.Overview.CompressDatabase.CaptureBitmap (sBitmap, rPos)
			[ ] // Print ("Bitmap for UnCheck state of CheckBox captured and stored in {sBitmap}")
			[ ] // CleanUpCompanyData.PageList1.Overview.CompressDatabase.Click ()
			[+] // if PointOfSaleMessage.Exists (2)
				[ ] // PointOfSaleMessage.OK.Click ()
			[ ] // sBitmap = "{sBitmapPath}\LCheckBox2.bmp"
			[ ] // CleanUpCompanyData.PageList1.Overview.CompressDatabase.CaptureBitmap (sBitmap, rPos)
			[ ] // Print ("Bitmap for Check state of CheckBox captured and stored in {sBitmap}")
			[ ] // CleanUpCompanyData.PageList1.Overview.CompressDatabase.Click ()
			[ ] // CleanUpCompanyData.Leave.Click ()
		[ ] 
	[+] STRING GetIP ()
		[ ] STRING sCmdLine = "ipconfig", sTemp, sPattern
		[ ] LIST OF STRING lsOutput
		[ ] INTEGER iLen
		[ ] SYS_Execute (sCmdLine, lsOutput)
		[ ] iLen = ListCount (lsOutput)
		[+] switch (GetGuiType ())
			[+] case mswxp, mswxp64
				[ ] sPattern = "IP Address"
			[+] case msw2003, msw2003_64
				[ ] sPattern = "IP Address"
			[+] case mswvista, mswvista_64
				[ ] sPattern = "IPv4 Address"
			[+] case mswin7, mswin7_64
				[ ] sPattern = "IPv4 Address"
			[+] // case mswin8, mswin8_64
				[ ] // sPattern = "IPv4 Address"
			[+] case mswin2008, mswin2008_64
				[ ] sPattern = "IPv4 Address"
		[+] while (MatchStr ("*{sPattern}*", lsOutput[iLen]) != TRUE)
			[ ] iLen--
		[ ] sTemp = GetField (lsOutput[iLen], ":", 2)
		[ ] return Right (sTemp, (Len (sTemp) -1))
	[+] STRING GetName ()
		[ ] return SYS_GetEnv ("COMPUTERNAME")
	[+] STRING GetServerIP ()
		[ ] HINIFILE hCS
		[ ] STRING sIP
		[ ] hCS = IniFileOpen (sCSEnvFile)
		[ ] sIP = IniFileGetValue (hCS, "Server", "IP")
		[ ] IniFileClose (hCS)
		[ ] return sIP
	[+] STRING GetServerName ()
		[ ] HINIFILE hCS
		[ ] STRING sName
		[ ] hCS = IniFileOpen (sCSEnvFile)
		[ ] sName = IniFileGetValue (hCS, "Server", "MName")
		[ ] IniFileClose (hCS)
		[ ] return sName
	[+] STRING GetAdditionalUserLicense (STRING sSKU1)
		[+] switch sSKU1
			[+] case "MULTISTORE"
				[ ] return sAdditionalLicenseMultistore
			[+] case "PRO"
				[ ] return sAdditionalLicensePro
			[+] case "BASIC"
				[ ] return sAdditionalLicenseBasic
	[+] STRING GetRegistrationCode (STRING sSKU1)
		[-] switch sSKU1
			[-] case "MULTISTORE"
				[ ] return sRegCodeMultistore
			[+] case "PRO"
				[ ] return sRegCodePro
			[+] case "BASIC"
				[ ] return sRegCodeBasic
	[+] STRING GetOnDemandID ()
		[ ] HINIFILE hCS
		[ ] STRING sOnDemandID
		[ ] hCS = IniFileOpen (sTaskInfoFile)
		[ ] sOnDemandID = IniFileGetValue (hCS, "env", "REQUESTID")
		[ ] IniFileClose (hCS)
		[ ] return sOnDemandID
	[ ] 
[ ] 
[-] // VERIFICATIONS
	[+] type SubtestStatus is enum
		[ ] ContinueSubtest
		[ ] EndSubtest
	[ ] 
	[-] BOOLEAN VerifySafely (ANYTYPE aActual, ANYTYPE aExpected, STRING sMessage)
		[-] do
			[ ] Verify (aActual, aExpected, sMessage)
			[ ] Print ("Verified: '{sMessage}' - '{aActual}'")
			[ ] ListAppend (lrMaster, {sMessage, TRUE, aActual, NULL})
			[ ] return TRUE
		[-] except
			[ ] ExceptLog ()
			[ ] Print ("")
			[ ] ListAppend (lrMaster, {sMessage, FALSE, aActual, aExpected})
			[ ] return FALSE
		[ ] 
	[ ] 
	[+] VerifyFatal (ANYTYPE aActual, ANYTYPE aExpected, STRING sMessage)
		[+] do
			[ ] Verify (aActual, aExpected, sMessage)
			[ ] Print ("Verified: '{sMessage}' - '{aActual}'")
			[ ] ListAppend (lrMaster, {sMessage, TRUE, aActual, NULL})
		[+] except
			[ ] ListAppend (lrMaster, {sMessage, FALSE, aActual, aExpected})
			[ ] reraise
	[ ] 
	[+] BOOLEAN VerifyPartial (STRING sActual, STRING sPattern, STRING sMessage)
		[ ] BOOLEAN bRes
		[ ] bRes = MatchStr (sPattern, sActual)
		[+] if (bRes)
			[ ] return VerifySafely (sActual, sActual, sMessage)
		[+] else
			[ ] return VerifySafely (sActual, sPattern, sMessage)
[ ] 
