﻿[ ] // *****************************************************************************************************************************************************************************************
[+] // TEST DESCRIPTION
	[ ] // Test Goal: Sending sales receipts of payment methods "Charge to Account" and "Payment on Account" from POS and 
	[ ] // 			   verifying the "Accounts Receivable" effected in QB
	[+] // Test Steps:
		[ ] // 1. Connect to QuickBooks
		[ ] // 2. Create a sale by "Charge to account" payment and get the total amount
		[ ] // 3. Create a sale to "Make payment on account"
		[ ] // 4. Invoke Sales History (Result 1)
		[ ] // 5. Click on "Topbar.Home"
		[ ] // 6. Goto Financial-> Update QuickBooks (Result 2)
	[+] // Expected Result:
		[ ] // 1. Verify sales created
		[ ] // 2. Verify Financial Exchange dialog appears
[ ] // TESTCASE::FESalesReceiptChargeToAccount
[ ] // ATC ID::
[ ] // COMPANY FILE PATH::S:\POS_CompanyFile\21.0\ConsoleDB1.qpb
[ ] // *****************************************************************************************************************************************************************************************
[ ] // TESTSCRIPT::FESalesReceiptChargeToAccount.t
[ ] // OWNER::POSAutomation Team
[ ] // AUTHOR::Mahalakhmi
[ ] // *****************************************************************************************************************************************************************************************
[ ] 
[+] testcase FE_SalesReceiptChargeToAccount ()
	[+] // VARIABLES
		[ ] STRING sCompanyFile, sTotalAmount, sItem, sCustomer, sPaymentMode, sCreditLimit
		[ ] LIST OF STRING lsSalesExpected
	[ ] 
	[+] // SETUP
		[ ] sCompanyFile = "POSV10_FE1.qpb"
		[ ] UpdateCompanyFile (sCompanyFile)
	[ ] 
	[+] // STEPS
		[+] // Step 1: Connect to QuickBooks
			[ ] ConnectToQB ()
		[ ] 
		[+] // Step 2: Create a sale by "Charge to account" payment and get the total amount
			[ ] sItem = "InvItem2"
			[ ] sCustomer = "Cust1L, Cust1F"
			[ ] sPaymentMode = "Account"
			[ ] sCreditLimit = "1000"
			[ ] SalesReceipt.Sale.Invoke ()
			[ ] SalesReceipt.Sale.EnterItems.SelectItem (sItem)
			[ ] SalesReceipt.Sale.EnterCustomer.SelectCustomer (sCustomer)
			[ ] SalesReceipt.Sale.PaymentButtons.Account.Click ()
			[ ] SalesReceipt.Sale.AccountPayment.Save.Click ()
			[+] if (SalesReceipt.Confirmation.Exists (3))
				[ ] SalesReceipt.Confirmation.Yes.Click ()
			[+] if SalesReceipt.Sale.AccountPayment.Exists ()
				[ ] SalesReceipt.Sale.AccountPayment.CreditLimit.SetData (sCreditLimit)
				[ ] SalesReceipt.Sale.AccountPayment.UseChargeAccountForThisCustomer.Click ()
			[+] if (SalesReceipt.Confirmation.Exists (3))
				[ ] SalesReceipt.Confirmation.Yes.Click ()
			[ ] sTotalAmount = SalesReceipt.Sale.SubTotal.Total.GetCaption ()
			[ ] SalesReceipt.Sale.SaveOnly.Click ()
		[ ] 
		[+] // Step 3: Create a sale to "Make payment on account"
			[ ] SalesReceipt.Sale.EnterCustomer.SelectCustomer (sCustomer)
			[ ] SalesReceipt.Sale.PaymentButtons.Account.Click ()
			[ ] SalesReceipt.Sale.AccountPayment.MakePaymentOnAccount.Check ()
			[ ] SalesReceipt.Sale.AccountPayment.PaymentAmount.SetData (Str (Val(sTotalAmount)/2)) // Making half payment on account
			[ ] SalesReceipt.Sale.AccountPayment.Save.click ()
			[ ] SalesReceipt.Sale.PaymentButtons.Cash.Click ()
			[ ] SalesReceipt.Sale.CashPayment.ExactAmount.Click ()
			[ ] SalesReceipt.Sale.CashPayment.Save.Click ()
			[ ] SalesReceipt.Sale.SaveOnly.Click ()
			[ ] SalesReceipt.Sale.Cancel.Click ()
		[ ] 
		[+] // Step 4: Invoke Sales History
			[ ] SalesHistory.SalesList.Invoke ()
			[ ] Sleep (3)
		[ ] 
		[+] // Result 1: Verify sales created
			[ ] RemoveGridColumn ("SaleDate")
			[+] lsSalesExpected = {...}
				[ ] "Regular Sales 1 1 Cust1F Cust1L 1 210.00 1 Account"
				[ ] "Regular Sales 1 2 Cust1F Cust1L 1 105.00 1 Cash"
			[ ] VerifySafely (SalesHistory.SalesList.SalesGrid.ItemTexts, lsSalesExpected, "Sales created and displayed in sales history")
		[ ] 
		[+] // Step 5: Click on "Topbar.Home"
			[ ] SalesHistory.SalesList.Topbar.Home.Click ()
		[ ] 
		[+] // Step 6: Goto Financial-> Update QuickBooks
			[ ] QuickBooksPointOfSale.Financial.OpenSubmenu ()
			[ ] QuickBooksPointOfSale.Financial.UpdateQuickBooks.Click ()
		[ ] 
		[+] // Result 2: Verify Financial Exchange dialog appears
			[ ] VerifySafely (FinancialExchange.Exists (3), TRUE, "Financial Exchange dialog appears")
	[ ] 
	[+] // CLEANUP
		[ ] WaitFor (FinancialExchange.Close, iTimeOut*8)
		[ ] FinancialExchange.Close.Click ()
		[ ] DisconnectQB ()
[ ] 
