﻿[ ] // *****************************************************************************************************************************************************************************************
[+] // TEST DESCRIPTION
	[ ] // Test Goal: Verifying editing sales tax code and sending a sales receipt for a taxable item and a non taxable item from POS to QB
	[+] // Test Steps:
		[ ] // 1. Connect to QuickBooks
		[ ] // 2. Invoke company preferences and Goto Sales Tax 
		[ ] // 3. Click on "Edit Tax Code" button of code "Tax" (Result 1)
		[ ] // 4. Edit the sales tax code to change the tax rate to 8% and save the preference changes
		[ ] // 5. Create a non taxable item
		[ ] // 6. Create a Sale for a taxable and a non taxable item (Result 2)
		[ ] // 7. Goto Financial-> Update QuickBooks (Result 3)
	[+] // Expected Result:
		[ ] // 1. Verify 'Edit Tax Code' dialog appears
		[ ] // 2. Verify sale is created
		[ ] // 3. Verify Financial Exchange dialog appears
[ ] // TESTCASE::FE_SalesTax
[ ] // ATC ID::
[ ] // COMPANY FILE PATH::S:\POS_CompanyFile\21.0\ConsoleDB1.qpb
[ ] // *****************************************************************************************************************************************************************************************
[ ] // TESTSCRIPT::FE_SalesTax.t
[ ] // OWNER::POSAutomation Team
[ ] // AUTHOR::Mahalakhmi
[ ] // *****************************************************************************************************************************************************************************************
[ ] 
[+] testcase FE_SalesTax ()
	[+] // VARIABLES
		[ ] STRING sCompanyFile, sTaxCodeName, sTaxRate
		[ ] LIST OF STRING lsSalesExpected
		[ ] NewItemRec nir
		[ ] SalesReceiptRec srr
	[ ] 
	[+] // SETUP
		[ ] sCompanyFile = "POSV10_FE1.qpb"
		[ ] UpdateCompanyFile (sCompanyFile)
	[ ] 
	[+] // STEPS
		[+] // Step 1: Connect to QuickBooks
			[ ] ConnectToQB ()
		[ ] 
		[+] // Step 2: Invoke company preferences and Goto Sales Tax 
			[ ] Preferences.CompanyPreferences.Invoke ()
			[ ] Preferences.CompanyPreferences.TreeView.Select ("Financial")
			[+] if ConnectingToQB.ConnectingToQuickBooks.Exists (10)
				[ ] WaitGone (ConnectingToQB.ConnectingToQuickBooks, iTimeOut*5)
				[+] if ConnectingToQB.ConnectingToQuickBooks.Exists (10)
					[ ] WaitGone (ConnectingToQB.ConnectingToQuickBooks, iTimeOut*5)
			[ ] WaitUntillEnabled (Preferences.CompanyPreferences.TreeView, TRUE, iTimeOut*2)
			[ ] Preferences.CompanyPreferences.TreeView.Collapse ("Sales")
			[+] if ConnectingToQB.ConnectingToQuickBooks.Exists (10)
				[ ] WaitGone (ConnectingToQB.ConnectingToQuickBooks, iTimeOut*5)
				[+] if ConnectingToQB.ConnectingToQuickBooks.Exists (10)
					[ ] WaitGone (ConnectingToQB.ConnectingToQuickBooks, iTimeOut*5)
			[ ] WaitUntillEnabled (Preferences.CompanyPreferences.TreeView, TRUE, iTimeOut*2)
			[ ] Preferences.CompanyPreferences.TreeView.Select ("Sales Tax")
			[+] if ConnectingToQB.ConnectingToQuickBooks.Exists (10)
				[ ] WaitGone (ConnectingToQB.ConnectingToQuickBooks, iTimeOut*5)
				[+] if ConnectingToQB.ConnectingToQuickBooks.Exists (10)
					[ ] WaitGone (ConnectingToQB.ConnectingToQuickBooks, iTimeOut*5)
			[ ] WaitUntillEnabled (Preferences.CompanyPreferences.PageList.SalesTax.Taxes, TRUE, iTimeOut*2)
		[ ] 
		[+] // Step 3: Click on "Edit Tax Code" button of code "Tax"
			[ ] Preferences.CompanyPreferences.PageList.SalesTax.Taxes.TL1Tax.EditTaxCode.Click ()
		[ ] 
		[+] // Result 1: Verify 'Edit Tax Code' dialog appears
			[ ] VerifySafely (EditTaxCode.Exists (3), TRUE, "Edit tax Code dialog appears")
		[ ] 
		[+] // Step 4: Edit the sales tax code to change the tax rate to 8% and save the preference changes
			[ ] sTaxCodeName = "Tax8"
			[ ] sTaxRate = "8"
			[ ] EditTaxCode.PageList.Sheet1.TaxCodeName.TaxCodeName.SetText (sTaxCodeName)
			[ ] EditTaxCode.Next.Click ()
			[ ] EditTaxCode.Next.Click ()
			[ ] EditTaxCode.PageList.Sheet3.TaxRate.SetText (sTaxRate)
			[ ] EditTaxCode.Finish.Click ()
			[ ] WaitFor (Preferences.BottomBar.Save, 5)
			[ ] Preferences.BottomBar.Save.Click ()
			[ ] WaitUntill (QuickBooksPointOfSale.File, "IsEnabled", TRUE)
		[ ] 
		[+] // Step 5: Create a non taxable item
			[ ] nir = {}
			[ ] nir.sItemName = "NonTaxItem1"
			[ ] nir.sDepartment = "System"
			[ ] nir.sOnHandQty = "20"
			[ ] nir.sRegularPrice = "100"
			[ ] Items.ItemsList.AddInventoryItem.Invoke ()
			[ ] FillItemForm (nir)
			[ ] Items.ItemsList.AddInventoryItem.ScrollViewer.BasicInfo.OnHandQty.SetFocus ()
			[ ] Items.ItemsList.AddInventoryItem.TypeKeys ("<Tab><n>") // To select "Non" in the Tax dropdown menu
			[ ] Items.ItemsList.AddInventoryItem.Save.Click ()
			[ ] Items.ItemsList.Topbar.Home.Click ()
		[ ] 
		[+] // Step 6: Create a Sale for a taxable and a non taxable item
			[ ] srr = {}
			[ ] srr.srp = {}
			[+] srr.lsItems = {...}
				[ ] "InvItem1"
				[ ] "{nir.sItemName}"
			[ ] srr.srp.sPaymentMode = "Cash"
			[ ] srr.sButton = "Save"
			[ ] srr.bExitSales = TRUE
			[ ] CreateSalesReceipt (srr)
		[ ] 
		[+] // Result 2: Verify sale is created
			[ ] SalesHistory.Invoke ()
			[ ] RemoveGridColumn ("SaleDate")
			[+] lsSalesExpected = {...}
				[ ] "Regular Sales 1 1 2 208.00 2 Cash"
			[ ] VerifySafely (SalesHistory.SalesList.SalesGrid.ItemTexts, lsSalesExpected, "Sales created and displyes in sales history")
			[ ] SalesHistory.SalesList.Topbar.Home.Click ()
		[ ] 
		[+] // Step 7: Goto Financial-> Update QuickBooks
			[ ] QuickBooksPointOfSale.Financial.OpenSubmenu ()
			[ ] QuickBooksPointOfSale.Financial.UpdateQuickBooks.Click ()
		[ ] 
		[+] // Result 3: Verify Financial Exchange dialog appears
			[ ] VerifySafely (FinancialExchange.Exists (3), TRUE, "Financial Exchange dialog appears")
	[ ] 
	[+] // CLEANUP
		[ ] WaitFor (FinancialExchange.Close, iTimeOut*10)
		[ ] FinancialExchange.Close.Click ()
		[ ] DisconnectQB ()
[ ] 
