﻿[ ] // *****************************************************************************************************************************************************************************************
[+] // TEST DESCRIPTION
	[ ] // Test Goal: Verifying the preference setting for 'Require a Customer Entry On All Receipts'
	[+] // Test Steps:
		[ ] // 1: Invoke preferences and select 'Customers'
		[ ] // 2: Check the check box 'Require A Customer Entry On All Receipts' and click 'Save'
		[ ] // 3: Open new sales receipt (Result 1)
		[ ] // 4: Enter an item and click 'Cash' (Result 2)
		[ ] // 5: Click 'Ok'.
	[+] // Expected Result:
		[ ] // 1: Verify new sales receipt opens up
		[ ] // 2: Verify message box pops up saying "An entry must be made in the "Customer" field before the record can be saved."
[ ] // TESTCASE::Prefs_CustomerEntryInReceipt
[ ] // ATC ID::POS_FILE_ATC_033
[ ] // COMPANY FILE PATH::S:\POS_CompanyFile\21.0\ConsoleDB1.qpb
[ ] // *****************************************************************************************************************************************************************************************
[ ] // TESTSCRIPT::Prefs_CustomerEntryInReceipt.t
[ ] // OWNER::POSAutomation Team
[ ] // AUTHOR::Mahalakshmi
[ ] // *****************************************************************************************************************************************************************************************
[ ] 
[+] testcase Prefs_CustomerEntryInReceipt ()
	[+] // VARIABLES
		[ ] STRING sCompanyFile, sMsg1, sMsg2, sNewCustType1, sNewCustType2
		[ ] SalesReceiptRec srr
		[ ] LIST OF STRING lsExpectedCustTypes
	[ ] 
	[+] // SETUP
		[ ] sCompanyFile = "ConsoleDB1.qpb"
		[ ] UpdateCompanyFile (sCompanyFile)
	[ ] 
	[+] // STEPS
		[+] // Step 1: Invoke preferences and select 'Customers'
			[ ] Preferences.CompanyPreferences.Invoke ()
			[ ] Preferences.CompanyPreferences.TreeView.Select ("Customers")
		[ ] 
		[+] // Step 2: Check the check box 'Require A Customer Entry On All Receipts' and click 'Save'
			[ ] Preferences.CompanyPreferences.PageList.Customers.CustomerTrackingOptions.RequireACustomerEntryOnAllReceipts.Click ()
			[ ] Preferences.BottomBar.Save.Click ()
			[ ] WaitUntill (QuickBooksPointOfSale.File, "IsEnabled", TRUE)
		[ ] 
		[+] // Step 3: Open new sales receipt
			[ ] SalesReceipt.Sale.Invoke ()
		[ ] 
		[+] // Result 1: Verify new sales receipt opens up
			[ ] VerifySafely (SalesReceipt.Sale.Exists (5), TRUE, "New sales receipt appears")
		[ ] 
		[+] // Step 4: Enter an item and click 'Cash'
			[ ] srr = {}
			[ ] srr.srp = {}
			[+] srr.lsItems = {...}
				[ ] "InvItem1"
			[ ] CreateSalesReceipt (srr)
			[ ] SalesReceipt.Sale.PaymentButtons.Cash.Click ()
		[ ] 
		[+] // Result 2: Verify message box pops up saying "An entry must be made in the "Customer" field before the record can be saved."
			[ ] sMsg1 = "Required field not completed"
			[ ] sMsg2 = "An entry must be made in the ""Customer"" field before the record can be saved."
			[ ] Verifysafely (QuickBooksPointOfSale.Information.VerifyMessage (sMsg1), TRUE, "Message is displayed")
			[ ] Verifysafely (QuickBooksPointOfSale.Information.VerifyMessage (sMsg2), TRUE, "Message is displayed")
		[ ]  
		[+] // Step 5: Click 'Ok'
			[ ] QuickBooksPointOfSale.Information.OK.Click ()
			[ ] SalesReceipt.Sale.Cancel.Click ()
			[+] if QuickBooksPointOfSale.Confirmation.Exists ()
				[ ] QuickBooksPointOfSale.Confirmation.DiscardChanges.Click ()
		[ ] 
		[+] // Step 6: Invoke preferences and select 'Customers'
			[ ] Preferences.CompanyPreferences.Invoke ()
			[ ] Preferences.CompanyPreferences.TreeView.Select ("Customers")
		[ ] 
		[+] // Step 7: Add two customer types
			[ ] sNewCustType1 = "NCT"
			[ ] Preferences.CompanyPreferences.PageList.Customers.CustomerType.AddCustomerType (sNewCustType1)
			[ ] sNewCustType2 = "NCTNCT"
			[ ] Preferences.CompanyPreferences.PageList.Customers.CustomerType.AddCustomerType (sNewCustType2)
			[ ] Preferences.BottomBar.Save.Click ()
			[ ] WaitUntill (QuickBooksPointOfSale.File, "IsEnabled", TRUE)
		[ ] 
		[+] // Step 8: Open new Customer form
			[ ] Customers.CustomerList.AddCustomer.Invoke ()
		[ ] 
		[-] // Result 3: Verify New customer types available for selection
			[ ] Customers.CustomerList.AddCustomer.ScrollViewer.CustomerSettings.CustomerType.BringIntoView ()
			[ ] Customers.CustomerList.AddCustomer.ScrollViewer.CustomerSettings.CustomerType.OpenSelector ()
			[+] lsExpectedCustTypes = {...}
				[ ] sNewCustType1
				[ ] sNewCustType2
			[ ] VerifySafely (Customers.CustomerList.AddCustomer.ScrollViewer.CustomerSettings.CustomerTypeSelector.GetCustTypes (), lsExpectedCustTypes, "Cust types added through preferences available for selection")
		[ ] 
		[+] // Step 9:  Click on Cancel
			[ ] Customers.CustomerList.AddCustomer.Cancel.Click ()
			[+] if Customers.Confirmation.Exists (3)
				[ ] Customers.Confirmation.Yes.Click ()
		[ ] 
		[+] // Step 10: Invoke preferences and select 'Customers'
			[ ] Preferences.CompanyPreferences.Invoke ()
			[ ] Preferences.CompanyPreferences.TreeView.Select ("Customers")
		[ ] 
		[+] // Step 11: Remove a customer type
			[ ] Preferences.CompanyPreferences.PageList.Customers.CustomerType.RemoveCustomerType (sNewCustType1)
			[ ] Preferences.BottomBar.Save.Click ()
			[ ] WaitUntill (QuickBooksPointOfSale.File, "IsEnabled", TRUE)
		[ ] 
		[+] // Step 12: Open new Customer form
			[ ] Customers.CustomerList.AddCustomer.Invoke ()
		[ ] 
		[-] // Result 3: Verify New customer types available for selection
			[ ] Customers.CustomerList.AddCustomer.ScrollViewer.CustomerSettings.CustomerType.BringIntoView ()
			[ ] Customers.CustomerList.AddCustomer.ScrollViewer.CustomerSettings.CustomerType.OpenSelector ()
			[+] lsExpectedCustTypes = {...}
				[ ] sNewCustType2
			[ ] VerifySafely (Customers.CustomerList.AddCustomer.ScrollViewer.CustomerSettings.CustomerTypeSelector.GetCustTypes (), lsExpectedCustTypes, "Cust types removed through preferences not available for selection")
	[ ] 
	[+] // CLEAN UP
		[ ] Customers.CustomerList.AddCustomer.Cancel.Click ()
		[+] if Customers.Confirmation.Exists (3)
			[ ] Customers.Confirmation.Yes.Click ()
[ ] 
